@@ -317,7 +317,7 @@ class Base_Page(Borg, unittest.TestCase):
                 else:
                     self.write(error_message, level='error')
 
-    def assert_false(self, condition, error_message=None, level='info'):
+    def assert_false(self, condition, pass_massage=None, error_message=None, level='info'):
         if self.non_breakable == 'N':
             assert_that(condition, equal_to(False), error_message)
         elif self.non_breakable == 'Y':
@@ -325,13 +325,13 @@ class Base_Page(Borg, unittest.TestCase):
             self.mini_check_counter += 1
             if level.lower() == "inverse":
                 if condition is True:
-                    self.write("action performed", level='error')
+                    self.write(error_message, level='error')
                 else:
-                    self.write(error_message, level='info')
+                    self.write("Expected results performed", level='info')
                     self.mini_check_pass_counter += 1
             else:
                 if condition is True:
-                    self.write("action performed", level='info')
+                    self.write(pass_massage, level='info')
                     self.mini_check_pass_counter += 1
                 else:
                     self.write(error_message, level='error')
